import { FormControl, FormGroup } from '@angular/forms';
import { Observable, Subject } from 'rxjs';
import { AuthProviders } from '../../enums/auth-providers.enum';
import { LoginFormType } from '../../enums/login-input-form.enum';
import { AuthModel } from '../../model/auth.models';
import { Language } from '../../model/language';
import { Theme } from '../../model/theme';
import { AuthIcons } from '../../types/auth-icons';
import { AuthModuleViewComponent } from './auth-module-view';
import * as i0 from "@angular/core";
export declare abstract class AbstractAuthService {
    private _loading$;
    loading$: Observable<boolean>;
    private _showBackBtn$;
    showBackBtn$: Observable<boolean>;
    private _secondsLeft$;
    secondsLeft$: Observable<number>;
    abstract icons: AuthIcons;
    abstract username: string;
    abstract languages: Language[];
    abstract themes: Theme[];
    abstract activeLanguageKey: string;
    abstract activeThemeKey: string;
    currentView: AuthModuleViewComponent;
    showFooter$: Subject<boolean>;
    formSwitcher$: Subject<FormGroup | FormControl>;
    constructor();
    setLoading(loading: boolean): void;
    setShowBackBtn(showBackBtn: boolean): void;
    setSecondsLeft(secondsLeft: number): void;
    abstract login(request: AuthModel): void;
    abstract socialLogin(provider: AuthProviders): void;
    abstract navigateToRegister(): void;
    abstract navigateToForgetPassword(email: string): void;
    abstract changeTheme(theme: string): void;
    abstract changeLanguage(lang: string): void;
    abstract sendForgetPasswordRequest(request: {
        email: string;
    }): void;
    abstract verifyForgetPasswordRequest(request: {
        email: string;
        code: string;
    }): void;
    abstract verifyForgetPasswordRequestResend(request: {
        email: string;
    }): void;
    abstract sendResetPasswordRequest(request: {
        password: string;
        email: string;
    }): void;
    abstract onLoginFormTypeChange(loginFormType: LoginFormType): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractAuthService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AbstractAuthService>;
}
