import { DecimalPipe } from '@angular/common';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { UntypedFormControl } from '@angular/forms';
import { MatSelect } from '@angular/material/select';
import { SafeHtml } from '@angular/platform-browser';
import moment from 'moment';
import { Observable, ReplaySubject } from 'rxjs';
import { FormFieldType } from '../../enums/form-field-type';
import { TooltipDirectionPreference } from '../../enums/tooltip-direction-preference';
import { SelectOption } from '../../model/select-option';
import * as i0 from "@angular/core";
export declare class FormFieldComponent implements OnInit, OnChanges, OnDestroy, AfterViewInit {
    private dateFormats;
    private decimalPipe;
    private changeDetectorRef;
    matSelect: MatSelect;
    textInput: ElementRef;
    readonly UNIQUE_RADIOGROUP_FORM_KEY: string;
    focused: boolean;
    passwordVisible: boolean;
    FormFieldType: typeof FormFieldType;
    private _dateFormat;
    dateInputPlaceholder: string;
    private componentDestroyed$;
    DirectionPreference: typeof TooltipDirectionPreference;
    searchOptions$: ReplaySubject<SelectOption<string | number | boolean>[]>;
    showEditor: boolean;
    selectOptions: SelectOption<string | number | boolean>[];
    editorContentStyle: string;
    fieldName: string;
    label: string;
    placeholder: string;
    message: string;
    useTooltips: boolean;
    descriptionText: string;
    formFieldControl: UntypedFormControl;
    submitted: boolean;
    required: boolean;
    type: FormFieldType;
    plusIconUrl: string;
    minusIconUrl: string;
    maxLength: number;
    max: number;
    min: number;
    pinValue: boolean;
    dualKnobs: boolean;
    reverseBarColor: boolean;
    set options(selectOptions: SelectOption<string | number | boolean>[]);
    iconHtml: SafeHtml;
    invalidPatternMessage: string;
    set dateFormat(format: string);
    dateInput: ElementRef;
    currencySymbol: string;
    hideCents: boolean;
    isEditable: boolean;
    rowEditConfirmationObsv: Observable<{
        fieldName: string;
        fieldValue: any;
    }>;
    errorInlineMode: boolean;
    showLabelInRequiredErrorMessage: boolean;
    decimalPosition: number;
    hyperlinkTarget: '_blank' | '_self' | '_parent' | '_top';
    readOnly: boolean;
    focus: boolean;
    showRequiredIndicator: boolean;
    maxDate: Date;
    minDate: Date;
    radioTranslateLabels: boolean;
    radioDeselectable: boolean;
    radioRippleEffect: boolean;
    rowEdit: EventEmitter<{
        fieldName: string;
        fieldValue: any;
    }>;
    focusOut: EventEmitter<void>;
    constructor(dateFormats: any, decimalPipe: DecimalPipe, changeDetectorRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    searchMultiSelect(query: string): void;
    private handleTypeUpdate;
    ngOnDestroy(): void;
    /**
     * A method to clear the value of the control name passed to it
     *
     * @param controlName - Name for control of cleared input
     */
    clear(): void;
    /**
     * @param $event - Object which contains date selected using mat-datepicker or entered manually by user
     *
     * Transform user entered date using provided dateFormat
     */
    processDate(value: null | moment.Moment | FocusEvent | string): void;
    processNumber(value: number | string): void;
    handleFocus(): void;
    handleFocusOut(event: FocusEvent): void;
    handleFieldClicked(event: any): void;
    handleClick(event: any): void;
    handleCheckboxOptionChange(): void;
    decrement(): void;
    increment(): void;
    /**
     * Toggles the display state of two radio button options.
     * However, This will work only when 'radioDeselectable' input property is 'true'
     *
     * @param {HTMLDivElement} radioActiveOption - The active radio button option.
     * @param {HTMLDivElement} radioInactiveOption - The inactive radio button option.
     * @return {void}
     */
    toggleRadioButton(radioActiveOption: HTMLDivElement, radioInactiveOption: HTMLDivElement): void;
    formFieldRadioOptionClick(radioOption: SelectOption<string | number | boolean>): void;
    togglePasswordVisibility(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormFieldComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FormFieldComponent, "lib-form-field", never, { "fieldName": { "alias": "fieldName"; "required": false; }; "label": { "alias": "label"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "message": { "alias": "message"; "required": false; }; "useTooltips": { "alias": "useTooltips"; "required": false; }; "descriptionText": { "alias": "descriptionText"; "required": false; }; "formFieldControl": { "alias": "formFieldControl"; "required": false; }; "submitted": { "alias": "submitted"; "required": false; }; "required": { "alias": "required"; "required": false; }; "type": { "alias": "type"; "required": false; }; "plusIconUrl": { "alias": "plusIconUrl"; "required": false; }; "minusIconUrl": { "alias": "minusIconUrl"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "max": { "alias": "max"; "required": false; }; "min": { "alias": "min"; "required": false; }; "pinValue": { "alias": "pinValue"; "required": false; }; "dualKnobs": { "alias": "dualKnobs"; "required": false; }; "reverseBarColor": { "alias": "reverseBarColor"; "required": false; }; "options": { "alias": "options"; "required": false; }; "iconHtml": { "alias": "iconHtml"; "required": false; }; "invalidPatternMessage": { "alias": "invalidPatternMessage"; "required": false; }; "dateFormat": { "alias": "dateFormat"; "required": false; }; "currencySymbol": { "alias": "currencySymbol"; "required": false; }; "hideCents": { "alias": "hideCents"; "required": false; }; "isEditable": { "alias": "isEditable"; "required": false; }; "rowEditConfirmationObsv": { "alias": "rowEditConfirmationObsv"; "required": false; }; "errorInlineMode": { "alias": "errorInlineMode"; "required": false; }; "showLabelInRequiredErrorMessage": { "alias": "showLabelInRequiredErrorMessage"; "required": false; }; "decimalPosition": { "alias": "decimalPosition"; "required": false; }; "hyperlinkTarget": { "alias": "hyperlinkTarget"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "focus": { "alias": "focus"; "required": false; }; "showRequiredIndicator": { "alias": "showRequiredIndicator"; "required": false; }; "maxDate": { "alias": "maxDate"; "required": false; }; "minDate": { "alias": "minDate"; "required": false; }; "radioTranslateLabels": { "alias": "radioTranslateLabels"; "required": false; }; "radioDeselectable": { "alias": "radioDeselectable"; "required": false; }; "radioRippleEffect": { "alias": "radioRippleEffect"; "required": false; }; }, { "rowEdit": "rowEdit"; "focusOut": "focusOut"; }, never, never, false, never>;
}
