import { CurrencyPipe } from '@angular/common';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { UntypedFormControl } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/paginator';
import { EditCompleteEvent, PrimeNgEditEvent } from '../../model/edit-complete-event';
import { FilterDataRequest } from '../../model/filter-data-request';
import { FilterDefinition } from '../../model/filter-definition';
import { GridColumn } from '../../model/grid-column';
import { GridColumnChange } from '../../model/grid-column-change';
import { GridDataRequest } from '../../model/grid-data-request';
import { GridFilterConfig } from '../../model/grid-filter-config';
import { GridRow } from '../../model/grid-row';
import { GridSortDirection } from '../../model/grid-sort-direction';
import { SelectOption } from '../../model/select-option';
import { GetDisplayValuePipe } from '../../pipes/get-display-value/get-display-value.pipe';
import { GridFilterService } from '../grid-filters/services/grid-filter.service';
import { GridService } from './grid.service';
import { GridMiscellaneousData } from './interfaces/grid-miscellaneous-data.interface';
import * as i0 from "@angular/core";
export declare class GridComponent<T = unknown> implements OnInit, OnChanges, OnDestroy, AfterViewInit {
    private dialog;
    private changeDetectorRef;
    private gridFilterService;
    private getDisplayValuePipe;
    private currencyPipe;
    private gridService;
    readonly defaultRowPerPageOptions: number[];
    readonly defaultRowsPerPage: number;
    hideToolbar: boolean;
    hideSettings: boolean;
    hideRowMenu: boolean;
    enableSelection: boolean;
    enableGridFilters: boolean;
    enableCreate: boolean;
    enableRefresh: boolean;
    enableTrash: boolean;
    isLoading: boolean;
    totalRecords: number;
    rowsPerPage: number;
    first: number;
    rowsPerPageOptions: number[];
    paginatorDataTypeLabel: string;
    selectAllConfirmButtonLabel: string;
    selectAllConfirmMsg: string;
    selectAllConfirmedMsg: string;
    selectAllExceptSomeRecordsConfirmedMsg: string;
    clearSelectionMsg: string;
    actionButtons: string[];
    currencyDisplayCode: string;
    minimumColumnWidth: number;
    set sortField(value: string);
    get sortField(): string;
    groupByField: GridColumn;
    gridFilterConfig: GridFilterConfig;
    set sortOrder(value: GridSortDirection);
    get sortOrder(): GridSortDirection;
    set columns(columns: GridColumn[]);
    get columns(): GridColumn[];
    set data(data: GridRow<T>[]);
    get data(): GridRow<T>[];
    filterDefinitions: FilterDefinition[];
    userFiltersList: FilterDataRequest[];
    dateFormat: string;
    maxPinnedColumns: number;
    errorInlineMode: boolean;
    gridMiscellaneousData?: GridMiscellaneousData;
    lazyLoad: EventEmitter<GridDataRequest>;
    columnsChange: EventEmitter<GridColumnChange>;
    editComplete: EventEmitter<EditCompleteEvent>;
    editChange: EventEmitter<boolean>;
    bulkDelete: EventEmitter<{
        selectedRows: GridRow<T>[];
    }>;
    selectAllPages: EventEmitter<boolean>;
    cellClicked: EventEmitter<{
        data: T;
        colName: string;
    }>;
    createClicked: EventEmitter<boolean>;
    refreshData: EventEmitter<boolean>;
    showTrash: EventEmitter<boolean>;
    actionButtonClicked: EventEmitter<{
        event: string;
        data: T;
    }>;
    excludeItem: EventEmitter<(string | number)[]>;
    paginator: Paginator;
    private _paginatorContainerRef;
    set paginatorContainerRef(value: ElementRef);
    display: boolean;
    selectedRows: GridRow<T>[];
    excludedRows: (string | number)[];
    processedData: GridRow<T>[];
    pagedProcessedData: GridRow<T>[];
    filteredColumns: GridColumn[];
    parsedSortOrder: number | null;
    editFormControl: UntypedFormControl;
    editSelectOptions: SelectOption<string | number | boolean>[];
    totalNumberOfPinnedColumns: number;
    columnManagementModalOpen: boolean;
    expanded: boolean;
    isEditInProgress: boolean;
    allRowsExpanded: boolean;
    selectAllPagesConfirmed: boolean;
    currentPage: number;
    private parsedSortField;
    private allColumns;
    searchString: string;
    private searchStringSubject;
    private componentDestroyed$;
    private userFilter;
    private lastChangedFieldValue;
    private didPaginate;
    private lazyLoadEvent;
    private firstChange;
    constructor(dialog: MatDialog, changeDetectorRef: ChangeDetectorRef, gridFilterService: GridFilterService, getDisplayValuePipe: GetDisplayValuePipe, currencyPipe: CurrencyPipe, gridService: GridService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private emitGridMiscellaneousData;
    private processDisplayValues;
    toggleAll(): void;
    onSelectionChange(rowsData: GridRow<T>[]): void;
    private setDisplayValue;
    isArray(data: any): boolean;
    onLazyLoad(event: LazyLoadEvent): void;
    handleSearchStringChange(query: string): void;
    paginate(event: {
        first: number;
        rows: number;
        page: number;
    }): void;
    private updatePaginationButtons;
    onSelectAllPages($event: any): void;
    onBulkDelete(): void;
    private emitLazyLoad;
    private validateConfig;
    private createMenuItems;
    openManagementModal(): void;
    handleEditComplete(event: PrimeNgEditEvent): void;
    handleEditInit(event: PrimeNgEditEvent): void;
    handleEditCancel(event: PrimeNgEditEvent): void;
    handleUnpinColumn(column: GridColumn, event: MouseEvent): void;
    colReorder(event: {
        columns: GridColumn[];
        dragIndex: number;
        dropIndex: number;
    }): void;
    colResize(event: any): void;
    calculateNumberAndPositionOfPinnedColumns(): void;
    handleApplyFilter(userFilter: FilterDataRequest): void;
    private getBtnElements;
    private expandAllGroups;
    private filterGridColumns;
    /**
     * Calculates the index of the first element on a specified page given the page number and rows per page.
     *
     * @param   {number} page         - The page number (0 is the 1st page).
     * @param   {number} rowsPerPage  - The number of rows per page.
     * @return {number}              - The index of the first element on the specified page.
     *
     * @example
     * // Returns 0 for the first page with 10 rows per page.
     * const firstElementIndex = getFirstNthOfPage(0, 10);
     *
     * // Returns 20 for the third page with 10 rows per page.
     * const thirdPageFirstElementIndex = getFirstNthOfPage(2, 10);
     */
    private getFirstNthOfPage;
    emitClickCellEvent(rowData: GridRow<T>, colName: string, controlType: string): void;
    emitRefreshEvent(): void;
    emitCreateEvent(): void;
    emitTrashEvent(event: boolean): void;
    emitActionButton(event: string, rowData: GridRow<T>): void;
    updateCurrentPage(currentPage: number): void;
    resetSelectedRows(): void;
    onRowSelected($event: GridRow<T>): void;
    onRowUnselected($event: GridRow<T>): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridComponent<any>, "lib-grid", never, { "hideToolbar": { "alias": "hideToolbar"; "required": false; }; "hideSettings": { "alias": "hideSettings"; "required": false; }; "hideRowMenu": { "alias": "hideRowMenu"; "required": false; }; "enableSelection": { "alias": "enableSelection"; "required": false; }; "enableGridFilters": { "alias": "enableGridFilters"; "required": false; }; "enableCreate": { "alias": "enableCreate"; "required": false; }; "enableRefresh": { "alias": "enableRefresh"; "required": false; }; "enableTrash": { "alias": "enableTrash"; "required": false; }; "isLoading": { "alias": "isLoading"; "required": false; }; "totalRecords": { "alias": "totalRecords"; "required": false; }; "rowsPerPage": { "alias": "rowsPerPage"; "required": false; }; "first": { "alias": "first"; "required": false; }; "rowsPerPageOptions": { "alias": "rowsPerPageOptions"; "required": false; }; "paginatorDataTypeLabel": { "alias": "paginatorDataTypeLabel"; "required": false; }; "selectAllConfirmButtonLabel": { "alias": "selectAllConfirmButtonLabel"; "required": false; }; "selectAllConfirmMsg": { "alias": "selectAllConfirmMsg"; "required": false; }; "selectAllConfirmedMsg": { "alias": "selectAllConfirmedMsg"; "required": false; }; "selectAllExceptSomeRecordsConfirmedMsg": { "alias": "selectAllExceptSomeRecordsConfirmedMsg"; "required": false; }; "clearSelectionMsg": { "alias": "clearSelectionMsg"; "required": false; }; "actionButtons": { "alias": "actionButtons"; "required": false; }; "currencyDisplayCode": { "alias": "currencyDisplayCode"; "required": false; }; "minimumColumnWidth": { "alias": "minimumColumnWidth"; "required": false; }; "sortField": { "alias": "sortField"; "required": false; }; "groupByField": { "alias": "groupByField"; "required": false; }; "gridFilterConfig": { "alias": "gridFilterConfig"; "required": false; }; "sortOrder": { "alias": "sortOrder"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "data": { "alias": "data"; "required": false; }; "filterDefinitions": { "alias": "filterDefinitions"; "required": false; }; "userFiltersList": { "alias": "userFiltersList"; "required": false; }; "dateFormat": { "alias": "dateFormat"; "required": false; }; "maxPinnedColumns": { "alias": "maxPinnedColumns"; "required": false; }; "errorInlineMode": { "alias": "errorInlineMode"; "required": false; }; "gridMiscellaneousData": { "alias": "gridMiscellaneousData"; "required": false; }; }, { "lazyLoad": "lazyLoad"; "columnsChange": "columnsChange"; "editComplete": "editComplete"; "editChange": "editChange"; "bulkDelete": "bulkDelete"; "selectAllPages": "selectAllPages"; "cellClicked": "cellClicked"; "createClicked": "createClicked"; "refreshData": "refreshData"; "showTrash": "showTrash"; "actionButtonClicked": "actionButtonClicked"; "excludeItem": "excludeItem"; }, never, never, false, never>;
}
