import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { ControlValueAccessor, NgControl, NgModel } from '@angular/forms';
import { PhoneNumberUtil } from 'google-libphonenumber';
import { Subject } from 'rxjs';
import { AppListbox, AppOption } from '../../directives/list-box-element/list-box';
import { CountryISO } from '../../enums/country-iso.enum';
import { PhoneNumberFormat as CustomPhoneNumberFormat } from '../../enums/phone-number-format.enum';
import { SearchCountryField } from '../../enums/search-country-field.enum';
import { ChangeData } from '../../model/change-data';
import { Country } from '../../model/country.model';
import { AuthIcons } from '../../types/auth-icons';
import { InputFieldComponent } from '../input-field/input-field.component';
import { CountryCode } from './data/country-code';
import * as i0 from "@angular/core";
export declare class TelInputComponent implements OnInit, OnChanges, OnDestroy, ControlValueAccessor {
    private countryCodeData;
    private cdr;
    ngControl: NgControl;
    inputElement: ElementRef<HTMLInputElement>;
    dropDownElementRef: ElementRef<HTMLDivElement>;
    countryList: ElementRef<HTMLUListElement>;
    focusableElRef: InputFieldComponent;
    phoneNumFieldNgModelRef: NgModel;
    listbox: AppListbox;
    optionsList: QueryList<AppOption<Country>>;
    value: string | undefined;
    enablePlaceholder: boolean;
    maskPhoneNumber: boolean;
    eagerMask: boolean;
    customPlaceholder: string;
    numberFormat: CustomPhoneNumberFormat;
    cssClass: string;
    onlyCountries: Array<string>;
    searchCountryFlag: boolean;
    searchCountryField: SearchCountryField[];
    searchCountryPlaceholder: string;
    maxLength: number;
    selectFirstCountry: boolean;
    selectedCountryISO: CountryISO;
    phoneValidation: boolean;
    inputId: string;
    separateDialCode: boolean;
    showDropDownArrow: boolean;
    icons: AuthIcons;
    readonly countryChange: EventEmitter<Country>;
    selectedCountry: Country;
    customPatterns: {
        A: {
            pattern: RegExp;
        };
    };
    phoneNumber: ChangeData | string | undefined;
    enableAutoCountrySelect: boolean;
    phoneMask: string;
    countryCode: string;
    allCountries: Array<Country>;
    filteredCountries: Array<Country>;
    phoneUtil: PhoneNumberUtil;
    disabled: boolean;
    countrySearchText: string;
    separateDialCodeClass: string;
    autoClose: boolean;
    clearTextOnSelect: boolean;
    freeInputMode: boolean;
    modelChangeEvent$: Subject<void>;
    private destroyRef$;
    onTouched: () => void;
    onChange: (_: ChangeData) => void;
    constructor(countryCodeData: CountryCode, cdr: ChangeDetectorRef, ngControl: NgControl);
    get isValidNumber(): boolean;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    init(): void;
    onDropDownShow(): void;
    toggleFreeInputMode(): void;
    private createPhoneMask;
    onListFocus(): void;
    setSelectedCountry(country: Country): void;
    /**
     * Search country based on country name, iso2, dialCode or all of them.
     */
    searchCountry(): void;
    private setActiveSelectedCountry;
    onPhoneNumberChange(changeFromModel?: boolean): void;
    private extractPhoneValue;
    onCountrySelect(country: Country, el: Pick<HTMLInputElement, 'focus'>, changeFromModel?: boolean, isClickUserGenerated?: boolean): void;
    onInputKeyPress(event: KeyboardEvent): void;
    private isValidInput;
    identify(index: number, item: Country): string;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    isString(val: ChangeData | string): val is string;
    isChangeDataObj(val: ChangeData | string): val is ChangeData;
    writeValue(obj: string | ChangeData): void;
    private convertStringToPhoneNumber;
    isValidFreeInput(inp: string): boolean;
    resolvePlaceholder(): string;
    focusInputElement(): void;
    focusPhoneField(): void;
    onResize(event: number): void;
    focusSelectedCountry(): void;
    /**
     * Returns parse PhoneNumber object.
     * @param phoneNumber string
     * @param countryCode string
     */
    private getParsedNumber;
    /**
     * Replace all digits is mask with '0' to remove character restrictions
     * @param mask
     * @private
     */
    private generalizeRestrictedMask;
    /**
     * extract All digits in a single string
     * @param mask
     * @private
     */
    private extractMaskInitialValues;
    /**
     * Adjusts input alignment based on the dial code presentation style.
     */
    private checkSeparateDialCodeStyle;
    /**
     * Cleans dialcode from phone number string.
     * @param phoneNumber string
     */
    private removeDialCode;
    /**
     * Sifts through all countries and returns iso code of the primary country
     * based on the number provided.
     * @param countryCode country code in number format
     * @param number PhoneNumber object
     */
    private getCountryIsoCode;
    /**
     * Gets formatted example phone number from phoneUtil.
     * @param countryCode string
     */
    protected getPhoneNumberPlaceHolder(countryCode: string): string;
    /**
     * Clearing the list to avoid duplicates (https://github.com/webcat12345/tel-input/issues/248)
     */
    protected fetchCountryData(): void;
    /**
     * Updates selectedCountry.
     */
    private updateSelectedCountry;
    private isArray;
    static ɵfac: i0.ɵɵFactoryDeclaration<TelInputComponent, [null, null, { self: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TelInputComponent, "lib-tel-input", never, { "value": { "alias": "value"; "required": false; }; "enablePlaceholder": { "alias": "enablePlaceholder"; "required": false; }; "maskPhoneNumber": { "alias": "maskPhoneNumber"; "required": false; }; "eagerMask": { "alias": "eagerMask"; "required": false; }; "customPlaceholder": { "alias": "customPlaceholder"; "required": false; }; "numberFormat": { "alias": "numberFormat"; "required": false; }; "cssClass": { "alias": "cssClass"; "required": false; }; "onlyCountries": { "alias": "onlyCountries"; "required": false; }; "searchCountryFlag": { "alias": "searchCountryFlag"; "required": false; }; "searchCountryField": { "alias": "searchCountryField"; "required": false; }; "searchCountryPlaceholder": { "alias": "searchCountryPlaceholder"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "selectFirstCountry": { "alias": "selectFirstCountry"; "required": false; }; "selectedCountryISO": { "alias": "selectedCountryISO"; "required": false; }; "phoneValidation": { "alias": "phoneValidation"; "required": false; }; "inputId": { "alias": "inputId"; "required": false; }; "separateDialCode": { "alias": "separateDialCode"; "required": false; }; "showDropDownArrow": { "alias": "showDropDownArrow"; "required": false; }; "icons": { "alias": "icons"; "required": false; }; }, { "countryChange": "countryChange"; }, never, never, false, never>;
}
