export declare enum ToggleVariants {
    /**
     * Basic Variant:
     * - This is the default toggle variant.
     * - In this variant, the toggle operates as a simple switch without any additional graphics or labels.
     * - No images or text will be displayed on the toggle when using this variant.
     * - The toggle will purely indicate its state (on/off) visually, typically by changing its background color or position.
     */
    Basic = "basic",
    /**
     * Image Variant:
     * - In this variant, the toggle button can display images on either side to represent its state.
     * - The `enable` and `disable` keys in the `ToggleGraphics` interface will define the images that are shown.
     *
     * - When the toggle is in the "off" state:
     *   - The image specified in the `enable` key will be shown on the left side of the toggle.
     *   - The image specified in the `disable` key will be shown on the right side of the toggle.
     *
     * - When the toggle is in the "on" state:
     *   - The image specified in the `disable` key will be shown on the left side of the toggle.
     *   - The image specified in the `enable` key will be shown on the right side of the toggle.
     *
     * - This variant is useful when you want to visually represent the toggle's state with icons or other graphics.
     */
    Image = "image",
    /**
     * Text Variant:
     * - In this variant, the toggle button can display text labels on either side to represent its state.
     * - The `enable` and `disable` keys in the `ToggleGraphics` interface will define the text that is shown.
     *
     * - When the toggle is in the "off" state:
     *   - The text specified in the `enable` key will be shown on the left side of the toggle.
     *   - The text specified in the `disable` key will be shown on the right side of the toggle.
     *
     * - When the toggle is in the "on" state:
     *   - The text specified in the `disable` key will be shown on the left side of the toggle.
     *   - The text specified in the `enable` key will be shown on the right side of the toggle.
     *
     * - This variant is ideal when you want to provide users with clear, descriptive labels indicating the toggle's current state.
     */
    Text = "text",
    MultipleImages = "multipleImages"
}
