export interface ToggleCircleMask {
    /**
     * Primary Mask:
     * - This string represents a unique identifier for the primary mask used in the toggle's SVG element.
     * - The `url(#id-here)` syntax in SVG only accepts an `id`, not a class, which is why a unique identifier is necessary.
     * - The primary mask is applied to the toggle's graphics when it is in the "on" state.
     * - It defines the area within the SVG where the "active" or "enabled" graphics (such as images or text) are shown.
     * - The unique `id` ensures that this mask is distinct from other toggles on the same page, preventing any interference or overlap.
     *
     * Example Usage:
     * - When the toggle is "on," the elements associated with this mask will be displayed on the appropriate side of the toggle.
     */
    primary: string;
    /**
     * Secondary Mask:
     * - This string represents a unique identifier for the secondary mask used in the toggle's SVG element.
     * - The `url(#id-here)` syntax in SVG only accepts an `id`, not a class, necessitating a unique identifier for each mask.
     * - The secondary mask is applied to the toggle's graphics when it is in the "off" state.
     * - It defines the area within the SVG where the "inactive" or "disabled" graphics (such as images or text) are shown.
     * - The unique `id` ensures that this mask is distinct from other toggles on the same page, avoiding any conflicts or misrendering.
     *
     * Example Usage:
     * - When the toggle is "off," the elements associated with this mask will be displayed on the appropriate side of the toggle.
     */
    secondary: string;
}
