export interface ToggleGraphics {
    /**
     * The `enable` key holds the value that will be displayed when the toggle is in the "on" state.
     * - For the 'image' variant: This should be the URL of the image that will appear on the active side of the toggle.
     * - For the 'text' variant: This should be the label or text that will appear when the toggle is active.
     * - When the toggle is in the "on" state:
     *   - If `enable` is defined, the image (or text) will be displayed on the right side of the toggle.
     *   - If the `variant` is 'text', this text will be visible on the right side.
     */
    enable?: string;
    /**
     * The `disable` key holds the value that will be displayed when the toggle is in the "off" state.
     * - For the 'image' variant: This should be the URL of the image that will appear on the inactive side of the toggle.
     * - For the 'text' variant: This should be the label or text that will appear when the toggle is inactive.
     * - When the toggle is in the "off" state:
     *   - If `disable` is defined, the image (or text) will be displayed on the right side of the toggle.
     *   - If the `variant` is 'text', this text will be visible on the left side.
     */
    disable?: string;
}
/**
 * Behavior of ToggleGraphics Interface:
 *
 * 1. Basic Variant:
 *    - When the variant is 'basic', no text or image will be displayed, and the toggle will act as a simple switch.
 *
 * 2. Image Variant:
 *    - When the toggle is in the "off" state:
 *      - On the left side of the toggle, the image source specified in the `enable` key will be displayed (if provided).
 *      - On the right side of the toggle, the image source specified in the `disable` key will be displayed (if provided).
 *    - When the toggle is in the "on" state:
 *      - The image source specified in the `disable` key will now be displayed on the left side.
 *      - The image source specified in the `enable` key will now be displayed on the right side.
 *
 * 3. Text Variant:
 *    - The functionality is the same as the 'image' variant, but instead of displaying images, the toggle will display text labels.
 *    - When the toggle is in the "off" state:
 *      - The text specified in the `enable` key will be shown on the left side.
 *      - The text specified in the `disable` key will be shown on the right side.
 *    - When the toggle is in the "on" state:
 *      - The text specified in the `disable` key will be shown on the left side.
 *      - The text specified in the `enable` key will be shown on the right side.
 */
