import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { SafeHtml } from '@angular/platform-browser';
import { Observable } from 'rxjs';
import { ItemSummary } from '../../model/item-summary';
import { TypeaheadResultsGroup } from '../../model/typeahead-results-group';
import * as i0 from "@angular/core";
export declare class TypeaheadResultComponent {
    groups: TypeaheadResultsGroup[];
    selectionFunc: (item: ItemSummary<any>) => void;
    alternateFunc: () => any;
    alternateText: string;
    loading: boolean;
    alternateCalled: EventEmitter<void>;
    /**
     * Method to execute passed in function if it is defined
     */
    handleAlternateFunction(): void;
    /**
     *
     * @param item - item that was selected
     *
     * A method to invoke passed in selection func with item if it is defined
     */
    itemSelected(item: ItemSummary<any>): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TypeaheadResultComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TypeaheadResultComponent, "lib-typeahead-result", never, { "groups": { "alias": "groups"; "required": false; }; "selectionFunc": { "alias": "selectionFunc"; "required": false; }; "alternateFunc": { "alias": "alternateFunc"; "required": false; }; "alternateText": { "alias": "alternateText"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; }, { "alternateCalled": "alternateCalled"; }, never, never, false, never>;
}
export declare class TypeaheadFieldComponent implements OnInit, OnDestroy {
    private changeDetectorRef;
    private renderer;
    entityFunctions: {
        searchFunction: (value: string) => Observable<any[]>;
        mappingFunction: (entity: any) => Observable<ItemSummary<any>>;
        filterFunction: (entity: any) => boolean;
        sortingFunction: (a: ItemSummary<any>, b: ItemSummary<any>) => number;
        resultGroupFunction?: (results: ItemSummary<any>[]) => TypeaheadResultsGroup[];
        entityMetadata?: {
            typeLabel: string;
            iconHtml: SafeHtml;
            placeholderText: string;
        };
    }[];
    selectedEntityIndex: number;
    selectionFunction: (item: ItemSummary<any>) => void;
    fieldName: string;
    placeholderText: string;
    resultLimit: number;
    alternateText: string;
    alternateFunction: (value: string) => any;
    error: string;
    set defaultText(value: string);
    defaultSearchString: string;
    suggestionText: string;
    required: boolean;
    isMultiselectMode: boolean;
    rowEditConfirmationObsv: Observable<{
        fieldName: string;
        fieldValue: any;
    }>;
    entitySelectMode: boolean;
    showRequiredIndicator: boolean;
    typeahead: ElementRef;
    searchResults: TypeaheadResultsGroup[];
    inputText: string;
    loading: boolean;
    displayResults: boolean;
    focused: boolean;
    private searchStringSubject;
    private inputStringSubject;
    private clickOutSubject;
    private componentDestroyed$;
    inputStringChange: Observable<string>;
    selected: EventEmitter<ItemSummary<any>>;
    deselected: EventEmitter<any>;
    constructor(changeDetectorRef: ChangeDetectorRef, renderer: Renderer2);
    ngOnInit(): void;
    ngOnDestroy(): void;
    private getSearchFuncs;
    /**
     *
     * A method to update search subject with user input
     *
     * @param searchString - User entered search string
     */
    search(searchString: string): void;
    /**
     *
     * A method to add recipient or attendee
     *
     * @param item - The ItemSummary that was selected
     */
    itemSelected(item: ItemSummary<any>): void;
    /**
     * Wraps the above method in a closure for consumption by the nested component
     */
    resultSelectFunc: (item: ItemSummary<any>) => void;
    /**
     * A method to notify parent when search bar clear is clicked
     */
    clear(): void;
    /**
     * Runs a search using the defaultSearchString when suggestion text is clicked
     */
    handleSuggestionClicked(): void;
    /**
     *
     * @param list - An Item Summary Array
     * @param searchString - String
     *
     * @return - A list of results
     *
     * This method sorts search results by most accurate according to the current search string. Begins after two characters typed.
     */
    private getListSortedByMostAccurateMatch;
    /**
     *
     * @param list - An Item Summary Array
     * @param searchString - String
     *
     * @return - An Array of lists, that each contain ItemSummaries that match different conditions to the search.
     *
     * This method is used by getListSortedByMostAccurateMatch to filter search results by placing them into sorted lists according to specific conditions measured against the search string value.
     */
    private breakListIntoSortSections;
    /**
     *
     * @param a - An Item Summary
     * @param b - An Item Summary
     *
     * @return - A number. -1 if b.header is > a.header, 0 if the same, and 1 if a.header > b.header
     */
    private sortByHeader;
    handleAlternateCalled(): void;
    handleFocus(): void;
    handleFocusOut(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TypeaheadFieldComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TypeaheadFieldComponent, "lib-typeahead-field", never, { "entityFunctions": { "alias": "entityFunctions"; "required": false; }; "selectedEntityIndex": { "alias": "selectedEntityIndex"; "required": false; }; "selectionFunction": { "alias": "selectionFunction"; "required": false; }; "fieldName": { "alias": "fieldName"; "required": false; }; "placeholderText": { "alias": "placeholderText"; "required": false; }; "resultLimit": { "alias": "resultLimit"; "required": false; }; "alternateText": { "alias": "alternateText"; "required": false; }; "alternateFunction": { "alias": "alternateFunction"; "required": false; }; "error": { "alias": "error"; "required": false; }; "defaultText": { "alias": "defaultText"; "required": false; }; "defaultSearchString": { "alias": "defaultSearchString"; "required": false; }; "suggestionText": { "alias": "suggestionText"; "required": false; }; "required": { "alias": "required"; "required": false; }; "isMultiselectMode": { "alias": "isMultiselectMode"; "required": false; }; "rowEditConfirmationObsv": { "alias": "rowEditConfirmationObsv"; "required": false; }; "entitySelectMode": { "alias": "entitySelectMode"; "required": false; }; "showRequiredIndicator": { "alias": "showRequiredIndicator"; "required": false; }; }, { "inputStringChange": "inputStringChange"; "selected": "selected"; "deselected": "deselected"; }, never, never, false, never>;
}
