import { SafeHtml } from '@angular/platform-browser';
import { Observable } from 'rxjs';
import { FormFieldType } from '../../enums/form-field-type';
import { FormActionConfig } from './form-action-config';
import { FormBannerConfig } from './form-banner-config';
import { FormCheckboxConfig } from './form-checkbox-config';
import { FormFieldVariables } from './form-field-variables';
import { FormIncrementerConfig } from './form-incrementer-config';
import { FormInjectableFormFieldConfig } from './form-injectable-form-field-config';
import { FormMultifieldConfig } from './form-multifield-config';
import { FormMultiselectConfig } from './form-multiselect-config';
import { FormNumberConfig } from './form-number-config';
import { FormRadioConfig } from './form-radio-config';
import { FormRatingConfig } from './form-rating-config';
import { FormSelectConfig } from './form-select-config';
import { FormTextlistConfig } from './form-textlist-config';
import { FormTimePickerConfig } from './form-time-picker-config';
import { FormTypeaheadConfig } from './form-typeahead-config';
/**
 * This class is used by the a to easily pass configuration info about form fields.
 * A convenience class, FormFieldStructureBuilder, is provided.
 */
export declare class FormFieldStructure {
    inputType: FormFieldType;
    fieldName: string;
    placeholder?: string;
    labelIcon?: SafeHtml;
    label?: string;
    required?: boolean;
    isHidden?: boolean;
    isInlineField?: boolean;
    maxLength?: number;
    validationPattern?: RegExp;
    patternErrorMessage?: string;
    selectConfig?: FormSelectConfig;
    typeaheadConfig?: FormTypeaheadConfig;
    multiselectConfig?: FormMultiselectConfig;
    radioConfig?: FormRadioConfig;
    checkboxConfig?: FormCheckboxConfig;
    textlistConfig?: FormTextlistConfig;
    timePickerConfig?: FormTimePickerConfig;
    multifieldConfig?: FormMultifieldConfig;
    actionConfig?: FormActionConfig;
    controlOptions?: any;
    flexBasisPct?: number;
    flexGrow: number;
    descriptionText?: string;
    fullLength?: boolean;
    message?: string;
    bannerConfig?: FormBannerConfig;
    disabled: boolean;
    isEditable?: boolean;
    confirmationObsv?: Observable<any>;
    handleConfirmation?: (event: any) => void;
    injectableFormFieldConfig?: FormInjectableFormFieldConfig;
    hyperlinkTarget?: string;
    numberConfig?: FormNumberConfig;
    showLabelInRequiredErrorMessage?: boolean;
    readOnly?: boolean;
    ratingConfig?: FormRatingConfig;
    incrementerConfig?: FormIncrementerConfig;
    constructor(inputType: FormFieldType, fieldName: string, placeholder?: string, labelIcon?: SafeHtml, label?: string, required?: boolean, isHidden?: boolean, isInlineField?: boolean, maxLength?: number, selectConfig?: FormSelectConfig, typeaheadConfig?: FormTypeaheadConfig, multiselectConfig?: FormMultiselectConfig, radioConfig?: FormRadioConfig, textlistConfig?: FormTextlistConfig, actionConfig?: FormActionConfig, validationPattern?: RegExp, patternErrorMessage?: string, controlOptions?: any, flexBasisPct?: number, flexGrow?: number, descriptionText?: string, fullLength?: boolean, multifieldConfig?: FormMultifieldConfig, message?: string, bannerConfig?: FormBannerConfig, disabled?: boolean, isEditable?: boolean, confirmationObsv?: Observable<any>, handleConfirmation?: (event: any) => void, injectableConfig?: FormInjectableFormFieldConfig, hyperlinkTarget?: string, checkboxConfig?: FormCheckboxConfig, numberConfig?: FormNumberConfig, showLabelInRequiredErrorMessage?: boolean, readOnly?: boolean, ratingConfig?: FormRatingConfig, incrementerConfig?: FormIncrementerConfig);
    /**
     * Converts this FormFieldStructure to FormFieldVariables, which can be consumed
     * by FormGenerator or MultiField.
     */
    convertStructureToVariables(): FormFieldVariables;
    private initFieldInfo;
    private convertTextlistStructureToVariables;
    private convertSelectStructureToVariables;
    private convertMultiselectStructureToVariables;
    private convertRadioStructureToVariables;
    private convertCheckboxStructureToVariables;
    private convertTypeaheadStructureToVariables;
    private convertMultifieldStructureToVariables;
    private convertActionStructureToVariables;
    private convertBannerStructureToVariables;
    private convertInjectableStructureToVariables;
    private convertRatingStructureToVariables;
    private convertIncrementerStructureToVariables;
    private convertNumberStructureToVariables;
}
export declare class FormFieldStructureBuilder {
    private inputType;
    private fieldName;
    private placeholder?;
    private labelIcon?;
    private label?;
    private required?;
    private isHidden?;
    private isEditable?;
    private isInlineField?;
    private maxLength?;
    private selectConfig?;
    private typeaheadConfig?;
    private multiselectConfig?;
    private radioConfig?;
    private textlistConfig?;
    private multifieldConfig?;
    private actionConfig?;
    private bannerConfig?;
    private validationPattern?;
    private patternErrorMessage?;
    private controlOptions?;
    private flexBasisPct?;
    private flexGrow;
    private descriptionText?;
    private fullLength?;
    private message?;
    private disabled;
    confirmationObsv?: Observable<any>;
    handleConfirmation?: (event: any) => void;
    private injectableConfig?;
    private hyperlinkTarget?;
    private checkboxConfig?;
    private numberConfig?;
    private showLabelInRequiredErrorMessage?;
    private readOnly;
    private ratingConfig?;
    private incrementerConfig?;
    constructor(inputType: FormFieldType, fieldName: string);
    setPlaceholder(placeholder: string): FormFieldStructureBuilder;
    setLabelIcon(labelIcon: SafeHtml): FormFieldStructureBuilder;
    setLabel(label: string): FormFieldStructureBuilder;
    setIsHidden(isHidden: boolean): FormFieldStructureBuilder;
    setRequired(required: boolean): FormFieldStructureBuilder;
    setMaxLength(maxLength: number): FormFieldStructureBuilder;
    setSelectConfig(selectConfig: FormSelectConfig): FormFieldStructureBuilder;
    setTypeaheadConfig(typeaheadConfig: FormTypeaheadConfig): FormFieldStructureBuilder;
    setMultiselectConfig(multiselectConfig: FormMultiselectConfig): FormFieldStructureBuilder;
    setRadioConfig(radioConfig: FormRadioConfig): FormFieldStructureBuilder;
    setIncrementerConfig(incrementerConfig: FormIncrementerConfig): FormFieldStructureBuilder;
    setTextlistConfig(textlistConfig: FormTextlistConfig): FormFieldStructureBuilder;
    setMultifieldConfig(multifieldConfig: FormMultifieldConfig): FormFieldStructureBuilder;
    setIsInlineField(isInlineField: boolean): FormFieldStructureBuilder;
    setControlOptions(controlOptions: any): FormFieldStructureBuilder;
    setValidationPattern(validationPattern: RegExp): FormFieldStructureBuilder;
    setPatternErrorMessage(patternErrorMessage: string): FormFieldStructureBuilder;
    setFlexGrow(flexGrow: number): FormFieldStructureBuilder;
    setFlexBasis(flexBasisPct: number): FormFieldStructureBuilder;
    setDescriptionText(descriptionText: string): FormFieldStructureBuilder;
    setFullLength(fullLength: boolean): FormFieldStructureBuilder;
    setActionConfig(actionConfig: FormActionConfig): FormFieldStructureBuilder;
    setBannerConfig(bannerConfig: FormBannerConfig): FormFieldStructureBuilder;
    setMessage(message: string): FormFieldStructureBuilder;
    setDisabled(disabled: boolean): FormFieldStructureBuilder;
    setConfirmationObsv(confirmationObsv: Observable<any>): this;
    setHandleConfirmation(handleConfirmation: (event: any) => void): this;
    setInjectableConfig(injectableConfig: FormInjectableFormFieldConfig): this;
    setHyperlinkTarget(hyperlinkTarget: string): FormFieldStructureBuilder;
    setCheckboxConfig(checkboxConfig: FormCheckboxConfig): FormFieldStructureBuilder;
    setNumberConfig(numberConfig: FormNumberConfig): FormFieldStructureBuilder;
    setShowLabelInRequiredErrorMessage(showLabel: boolean): FormFieldStructureBuilder;
    setReadOnly(readOnly: boolean): FormFieldStructureBuilder;
    setRatingConfig(ratingConfig: FormRatingConfig): FormFieldStructureBuilder;
    buildFormStructure(): FormFieldStructure;
}
