import { UntypedFormGroup } from '@angular/forms';
import { ItemActionHandler } from '../item-action-handler';
import { FormFieldVariables } from './form-field-variables';
/**
 * Variables used for displaying a form group within a form.
 * This includes support for creating the formgroup and adding field controls to that group.
 *
 * Section to place form fields within. If the form fields are inserted using class functions then the fields will be within formgroup.
 */
export declare class FormSectionVariables {
    fields: FormFieldVariables[][];
    formGroup: UntypedFormGroup;
    title: string;
    expanded: boolean;
    useSlideToggle: boolean;
    trackId: string;
    isHidden: boolean;
    footerAction: ItemActionHandler;
    headerActions: ItemActionHandler[];
    id: string;
    /**
     *
     * @param items - list of field info to be added to the group.
     *
     * Adds all fields into the group and inserts their controls into the form group.
     */
    addFieldInfo(controlAlreadyInForm: boolean, ...items: FormFieldVariables[]): void;
    /**
     *
     * @param item - item to be inserted
     *
     * Finds the matching existing form field and replaces it.
     */
    private replaceOldField;
    /**
     *
     * @param item - item to be attached
     *
     * Adds the new control to the group and adds the field to the list.
     */
    private addNewField;
    /**
     * This method sets a flexBasisPct value on any fields that do not have one manually set.
     * This is necessary in order to produce correct wrapping of form fields so that the
     * form is responsive to changing width.
     *
     * @param groupInfo - FormSectionVariables to calculate flex basis values for
     */
    calculateFlexBasis(): void;
    allFieldsHidden(): boolean;
}
